@@ -10,8 +10,7 @@
 [
   {
     'class_description' => 'Configuration class used by L<Config::Model> to edit or 
-validate /etc/ssh/ssh_config (when run as root)
-or ~/.ssh/config (when run as a regular user).
+validate ~/.ssh/config.
 ',
     'include_after' => 'Host',
     'name' => 'Ssh',
@@ -19,10 +18,10 @@ or ~/.ssh/config (when run as a regular user).
       'Ssh::HostElement'
     ],
     'copyright' => [
-      '2009-2011 Dominique Dumont'
+      '2009-2013 Dominique Dumont'
     ],
     'author' => [
-      'Dominique Dumont'
+      'Dominique Dumont <ddumon at cpan.org>'
     ],
     'license' => 'LGPL2',
     'element' => [
@@ -49,8 +48,17 @@ or ~/.ssh/config (when run as a regular user).
     ],
     'read_config' => [
       {
+        'default_layer' => {
+          'os_config_dir' => {
+            'darwin' => '/etc'
+          },
+          'file' => 'ssh_config',
+          'config_dir' => '/etc/ssh'
+        },
+        'auto_create' => '1',
+        'file' => 'config',
         'backend' => 'OpenSsh::Ssh',
-        'config_dir' => '/etc/ssh'
+        'config_dir' => '~/.ssh'
       }
     ]
   }
